@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2004, Industrial Light & Magic, a division of Lucas
+// Copyright (c) 2006, Industrial Light & Magic, a division of Lucas
 // Digital Ltd. LLC
 // 
 // All rights reserved.
@@ -32,29 +32,20 @@
 //
 ///////////////////////////////////////////////////////////////////////////
 
-
 #ifndef INCLUDED_IMF_INT64_H
 #define INCLUDED_IMF_INT64_H
 
 //----------------------------------------------------------------------------
 //
-//	Int64 -- unsigned 64-bit integers
+//	Int64 -- unsigned 64-bit integers, imported from namespace Imath
 //
 //----------------------------------------------------------------------------
 
-#include <limits.h>
+#include "ImathInt64.h"
 
 namespace Imf {
 
-
-#if defined PLATFORM_WINDOWS && _MSC_VER >= 1300
-    typedef unsigned __int64 Int64;
-#elif ULONG_MAX == 18446744073709551615LU
-    typedef long unsigned int Int64;
-#else
-    typedef long long unsigned int Int64;
-#endif
-
+using Imath::Int64;
 
 } // namespace Imf
 
